@@ -2,14 +2,14 @@
 #
 # associator.pm
 #
-# (C) Copyright IBM Corp. 2003
+# (C) Copyright IBM Corp. 2003, 2009
 #
-# THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE
+# THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE
 # ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE
 # CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
 #
-# You can obtain a current copy of the Common Public License from
-# http://oss.software.ibm.com/developerworks/opensource/license-cpl.html
+# You can obtain a current copy of the Eclipse Public License from
+# http://www.opensource.org/licenses/eclipse-1.0.php
 #
 # Author:       Heidi Neumann <heidineu@de.ibm.com>
 # Contributors: 
@@ -35,7 +35,7 @@ sub wbem_cli {
   my $e = $ENV{'SBLIM_TESTSUITE_VERBOSE'};
   if (defined $e) { print "\n>>${cmd} ${parm}<<\n"; }
   @enum = `${cmd} ${parm} 2>&1`;
-  return @enum
+   return @enum
 }
 
 
@@ -96,6 +96,7 @@ sub associators {
 
 sub exec_assoc {
   my ($class, $op, $ref, $target, $volatile) = @_;
+
   print $class." --- $op() - $ref to $target - started ";
   my $count = 0;
   my @rc = (0,"");
@@ -123,22 +124,21 @@ sub exec_assoc {
   foreach my $elem (@enum) {
     print ".";
     $count=0;
-
     chomp($elem);
 #    if    ( $op =~ /associatorNames/) { @assoc = `2>&1 wbemain -ac $class '${cimom::PROTOCOL}${elem}'`; 
-    if    ( $op =~ /associatorNames/) { @assoc = wbem_cli("wbemain", "${cimom::WBEMFLAG} -ac $class '${cimom::PROTOCOL}${elem}'"); 
-					$rc[3]="wbemain ${cimom::WBEMFLAG} -ac $class '${cimom::PROTOCOL}${elem}'";
+    if    ( $op =~ /associatorNames/) { @assoc = wbem_cli("wbemain", "${cimom::WBEMFLAG} -ac $class -arc $target '${cimom::PROTOCOL}${elem}'"); 
+					$rc[3]="wbemain ${cimom::WBEMFLAG} -ac $class -arc $target'${cimom::PROTOCOL}${elem}'";
 				      }
 #    elsif ( $op =~ /associators/ )    { @assoc = `2>&1 wbemai -ac $class '${cimom::PROTOCOL}${elem}'`; 
-    elsif ( $op =~ /associators/ )    { @assoc = wbem_cli("wbemai", "${cimom::WBEMFLAG} -ac $class '${cimom::PROTOCOL}${elem}'"); 
-					$rc[3]="wbemai -ac $class ${cimom::WBEMFLAG} '${cimom::PROTOCOL}${elem}'";
+    elsif ( $op =~ /associators/ )    { @assoc = wbem_cli("wbemai", "${cimom::WBEMFLAG} -ac $class -arc $target '${cimom::PROTOCOL}${elem}'"); 
+                                        $rc[3]="wbemai -ac $class -arc $target ${cimom::WBEMFLAG} '${cimom::PROTOCOL}${elem}'";
 				      }
     else { 
       print "... failed\n";
       return @rc; 
     }
-
-    if( defined $assoc[0] && defined $assoc[1]) {
+    
+   if( defined $assoc[0] && defined $assoc[1]) {
       if ( $assoc[0]=~/\*/ && $assoc[1]=~/${cimom::ERROR_PREFIX}/i) {
 	chomp($assoc[1]);
 	$assoc[1] =~ s/\* //;
@@ -155,7 +155,6 @@ sub exec_assoc {
 	return @rc;
       }
     }
-
     foreach my $assoc (@assoc) {
       print ".";
       if (!($assoc=~/$target\./i) && !($target=~/CIM_/i) ) {
