@@ -3,14 +3,14 @@
 #
 # interface.pl
 #
-# (C) Copyright IBM Corp. 2003
+# (C) Copyright IBM Corp. 2003, 2009
 #
-# THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE
+# THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE
 # ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE
 # CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
 #
-# You can obtain a current copy of the Common Public License from
-# http://oss.software.ibm.com/developerworks/opensource/license-cpl.html
+# You can obtain a current copy of the Eclipse Public License from
+# http://www.opensource.org/licenses/eclipse-1.0.php
 #
 # Author:       Heidi Neumann <heidineu@de.ibm.com>
 # Contributors: 
@@ -171,7 +171,6 @@ while ($line = <INPUT_CIM>) {
 	$line =~ s/objectPath : //;
 	$inst = $line;
       }
-      # test if class is volatile
       $line = <INPUT_CIM>;	
       chomp($line);
       if( $line =~ /modifyInst : /i ) {
@@ -180,6 +179,7 @@ while ($line = <INPUT_CIM>) {
 	$line = <INPUT_CIM>;
 	$volatile=1 if($line =~ /volatile/i);
       }
+      # test if class is volatile
       elsif($line =~ /volatile/i) { $volatile=1; }
     } # end of Instance specific Input
 
@@ -191,6 +191,12 @@ while ($line = <INPUT_CIM>) {
 	$line =~ s/objectPath : //;
 	$inst = $line;
       }
+      $line = <INPUT_CIM>;	
+      chomp($line);
+      if( $line =~ /modifyInst : /i ) {
+	$line =~ s/modifyInst : //;
+	$modifyInst = $line;
+      }
       my $read;
       foreach my $i (1 .. 4) {
         $read = <INPUT_CIM>;
@@ -262,13 +268,20 @@ while ($line = <INPUT_CIM>) {
 
       # modify (old name: set)
       if( $line =~ /modify$|set$/i ) {
-	if( !(defined $modifyInst) ) { print "failed modify() --- no sample Instance specified in cim/$CLASS.cim - fourth line\n\n"; exit 0; }
-	$TEST_OP=$INTERFACE_OP[3];
-	if($next=~/Expected Exception : /) { 
-	  $next=~s/Expected Exception : //;
-	  @rc=&check_returnedException($CLASS,$TEST_OP,$next,$modifyInst);
+	if( !(defined $modifyInst) ) { 
+	    print "failed modify() --- no sample Instance specified in cim/$CLASS.cim - skipped test\n\n"; 
+	    # reset rc
+	    @rc = (6,"failed modify() --- no sample Instance specified in cim/$CLASS.cim - skipped test");
+	    #exit 0; 
+	}
+	else {
+	    $TEST_OP=$INTERFACE_OP[3];
+	    if($next=~/Expected Exception : /) { 
+		$next=~s/Expected Exception : //;
+		@rc=&check_returnedException($CLASS,$TEST_OP,$next,$modifyInst);
+	    }
+	    else { @rc = &modify($CLASS,$inst,$modifyInst); }
 	}
-	else { @rc = &modify($CLASS,$inst,$modifyInst); }
       }
 
       # create
